summaryrefslogtreecommitdiff
path: root/settings.py
diff options
context:
space:
mode:
Diffstat (limited to 'settings.py')
-rw-r--r--settings.py37
1 files changed, 19 insertions, 18 deletions
diff --git a/settings.py b/settings.py
index 7571f0fc..57454f15 100644
--- a/settings.py
+++ b/settings.py
@@ -1,5 +1,5 @@
import os
# Django settings for archweb project.
## Set the debug values
DEBUG = False
@@ -13,7 +13,7 @@ ADMINS = ()
MANAGERS = ADMINS
# Package out-of-date emails for orphans
-NOTIFICATIONS = ['arch-notifications@archlinux.org']
+NOTIFICATIONS = ['dev@lists.parabola.nu']
# Full path to the data directory
DEPLOY_PATH = os.path.dirname(os.path.realpath(__file__))
@@ -161,39 +161,40 @@ PGP_SERVER = 'pgp.mit.edu'
PGP_SERVER_SECURE = True
# URL to fetch a current list of available ISOs
-ISO_LIST_URL = 'https://releng.archlinux.org/isos/'
+ISO_LIST_URL = 'https://repo.parabola.nu/iso/'
# URL for SVN access for fetching commit messages (note absence of packages or
# community bit on the end, repo.svn_root is appended)
-SVN_BASE_URL = 'svn://svn.archlinux.org/'
+#SVN_BASE_URL = 'svn://svn.archlinux.org/'
# URL for linking to mailing lists
-MAILMAN_BASE_URL = 'https://mailman.archlinux.org/'
+MAILMAN_BASE_URL = 'https://lists.parabola.nu/'
# URL for linking to the bugtracker
-BUGTRACKER_URL = 'https://bugs.archlinux.org/'
+BUGTRACKER_URL = 'https://labs.parabola.nu/'
# URL for linking to the release engineering/iso project on the bugtracker
-BUGTRACKER_RELENG_URL = 'https://bugs.archlinux.org/index.php?project=6'
+BUGTRACKER_RELENG_URL = 'https://labs.parabola.nu/projects/isos'
# URL for linking to projects in git
-PROJECTS_URL = 'https://projects.archlinux.org'
+PROJECTS_URL = 'https://projects.parabola.nu'
# Trackers used for ISO download magnet links
TORRENT_TRACKERS = (
- 'udp://tracker.archlinux.org:6969',
- 'http://tracker.archlinux.org:6969/announce',
+ 'udp://tracker.publicbt.com:80',
+ 'udp://tracker.openbittorrent.com:80',
+ 'udp://tracker.istole.it:80',
)
-DOMAIN_RE = r'^(.+\.)?archlinux.org$'
+DOMAIN_RE = r'^(.+\.)?parabola(\.nu|gnulinux\.org)$'
-BRANDING_APPNAME = 'archweb'
-BRANDING_DISTRONAME = 'Arch Linux'
-BRANDING_SHORTNAME = 'Arch'
-BRANDING_SLUG = 'archlinux'
-BRANDING_WIKINAME = 'ArchWiki'
-BRANDING_EMAIL = 'Arch Website Notification <nobody@archlinux.org>'
-BRANDING_OSEARCH_TAGS = 'linux archlinux package software'
+BRANDING_APPNAME = 'parabolaweb'
+BRANDING_DISTRONAME = 'Parabola GNU/Linux-libre'
+BRANDING_SHORTNAME = 'Parabola'
+BRANDING_SLUG = 'parabola'
+BRANDING_WIKINAME = 'ParabolaWiki'
+BRANDING_EMAIL = 'Parabola Website Notification <nobody@parabola.nu>'
+BRANDING_OSEARCH_TAGS = 'gnu linuxlibre parabola package software'
# Shorten some names just a bit
COUNTRIES_OVERRIDE = {
@@ -1,5 +1,5 @@
import os
-# Django settings for archweb project.
+# Django settings for parabolaweb project.
## Set the debug values
DEBUG = False